# Joystick eklentisi

JOYSTICK eklentisi trackballs ya da vidyo-oyun joysticklerinin girdilerini işler. Pygame Joystick modülünü kullanmak tuşları, aksisleri, analog tuşları ya da trackballs kullanmanıza izin verir.

## Tepki/yanıt değişkenleri ve seçenekler

JOYSTICK eklentisi KEYBOARD_RESPONSE ögesine benzer olarak çalışır. Daha fazla bilgi için KEYBOARD_RESPONSE-ögesinin yardım saysfasını ya da aşağıdaki linki ziyaret edin:

- <http://osdoc.cogsci.nl/3.2/manual/response/keyboard/>

## Tuş işimleri

Kullandığınız joysticke göre farklı sayıda tuş, analog eksenler bulunabilir. Lütfen hangi tuşun hangi işlevde olduğundan emin olunuz.
Daha fazla bilgi için:

- <http://osdoc.cogsci.nl/3.2/manual/response/joystick/>
